@@ -207,6 +207,12 @@ DMSSICNF COPY key: NameListFileIdAny. The list has to be accessible to the
 SMAPI servers.
 
 The length of namelist must no longer than 64.
+'''),
+    Opt('remotehost_sshd_port',
+        section='zvm',
+        default='22',
+        help='''
+The port number of remotehost sshd.
 '''),
     # image options
     Opt('sdk_image_repository',
@@ -566,7 +572,7 @@ class ConfigOpts(object):
         suffix = value[-1].upper()
         size = value[:-1]
         if (suffix not in ['G', 'M']) or (len(size) > 4) or (
-            size.strip('0123456789') is not ''):
+            size.strip('0123456789') != ''):
             raise OptFormatError("zvm", "user_default_max_memory", value)
 
     def _check_user_default_max_cpu(self, value):
