@@ -19,6 +19,7 @@ import six
 import sqlite3
 import threading
 import uuid
+import json
 
 from zvmsdk import config
 from zvmsdk import constants as const
@@ -176,6 +177,16 @@ class NetworkDbOperator(object):
                       "nic %s, port %s" %
                       (userid, interface, port))
 
+    def switch_add_record_migrated(self, userid, interface, switch,
+                             port=None, comments=None):
+        """Add userid and interfaces and switch into switch table."""
+        with get_network_conn() as conn:
+            conn.execute("INSERT INTO switch VALUES (?, ?, ?, ?, ?)",
+                         (userid, interface, switch, port, comments))
+            LOG.debug("New record in the switch table: user %s, "
+                      "nic %s, switch %s" %
+                      (userid, interface, switch))
+
     def switch_update_record_with_switch(self, userid, interface,
                                          switch=None):
         """Update information in switch table."""
@@ -260,6 +271,7 @@ class NetworkDbOperator(object):
 class FCPDbOperator(object):
 
     def __init__(self):
+        self._module_id = 'FCP'
         self._initialize_table()
 
     def _initialize_table(self):
@@ -285,6 +297,14 @@ class FCPDbOperator(object):
     def reserve(self, fcp):
         self._update_reserve(fcp, 1)
 
+    def is_reserved(self, fcp):
+        with get_fcp_conn() as conn:
+            result = conn.execute("SELECT * FROM fcp WHERE "
+                                  "fcp_id=?", (fcp,))
+            fcp_list = result.fetchall()
+            reserved = fcp_list[0][3]
+            return reserved == 1
+
     def find_and_reserve(self):
         with get_fcp_conn() as conn:
             result = conn.execute("SELECT * FROM fcp where connections=0 "
@@ -337,7 +357,14 @@ class FCPDbOperator(object):
                                   "fcp_id=?", (fcp,))
             fcp_list = result.fetchall()
             connections = fcp_list[0][2]
-            connections -= 1
+            if connections == 0:
+                msg = 'FCP with id: %s no connections in DB.' % fcp
+                LOG.error(msg)
+                obj_desc = "FCP with id: %s" % fcp
+                raise exception.SDKObjectNotExistError(obj_desc=obj_desc,
+                                                       modID=self._module_id)
+            else:
+                connections -= 1
             if connections < 0:
                 connections = 0
                 LOG.warning("Warning: connections of fcp is negative",
@@ -520,6 +547,15 @@ class GuestDbOperator(object):
                                                        modID=self._module_id)
         return guest
 
+    def add_guest_migrated(self, userid, meta, net_set,
+                             comments=None):
+        # Add guest which is migrated from other host.
+        guest_id = str(uuid.uuid4())
+        with get_guest_conn() as conn:
+            conn.execute(
+                "INSERT INTO guests VALUES (?, ?, ?, ?, ?)",
+                (guest_id, userid, meta, net_set, comments))
+
     def add_guest(self, userid, meta='', comments=''):
         # Generate uuid automatically
         guest_id = str(uuid.uuid4())
@@ -605,8 +641,9 @@ class GuestDbOperator(object):
             sql_cmd += " net_set=?,"
             sql_var.append(net_set)
         if comments is not None:
+            new_comments = json.dumps(comments)
             sql_cmd += " comments=?,"
-            sql_var.append(comments)
+            sql_var.append(new_comments)
 
         # remove the tailing comma
         sql_cmd = sql_cmd.strip(',')
@@ -623,6 +660,28 @@ class GuestDbOperator(object):
             guests = res.fetchall()
         return guests
 
+    def get_migrated_guest_list(self):
+        with get_guest_conn() as conn:
+            res = conn.execute("SELECT userid FROM guests "
+                               "WHERE comments LIKE '%\"migrated\": 1%'")
+            guests = res.fetchall()
+        return guests
+
+    def get_comments_by_userid(self, userid):
+        """ Get comments record.
+        output should be like: {'k1': 'v1', 'k2': 'v2'}'
+        """
+        userid = userid
+        with get_guest_conn() as conn:
+            res = conn.execute("SELECT comments FROM guests "
+                               "WHERE userid=?", (userid,))
+
+        result = res.fetchall()
+        comments = {}
+        if result[0][0]:
+            comments = json.loads(result[0][0])
+        return comments
+
     def get_metadata_by_userid(self, userid):
         """get metadata record.
         output should be like: "a=1,b=2,c=3"
