@@ -268,12 +268,25 @@ class VMAction(object):
 
         return info
 
-    @validation.schema(guest.live_resize_cpus)
-    def live_resize_cpus(self, userid, body):
-        cpu_cnt = body['cpu_cnt']
-        info = self.client.send_request('guest_live_resize_cpus',
-                                        userid, cpu_cnt)
+    @validation.schema(guest.register_vm)
+    def register_vm(self, userid, body):
+        meta = body['meta']
+        net_set = body['net_set']
+        info = self.client.send_request('guest_register',
+                                userid, meta, net_set)
+        return info
 
+    @validation.schema(guest.live_migrate_vm)
+    def live_migrate_vm(self, userid, body):
+        # dest_zcc_userid default as ''
+        dest_zcc_userid = body.get('dest_zcc_userid', '')
+        destination = body['destination']
+        operation = body.get('operation', {})
+        parms = body['parms']
+
+        info = self.client.send_request('guest_live_migrate',
+                                userid, dest_zcc_userid, destination,
+                                parms, operation)
         return info
 
     @validation.schema(guest.resize_cpus)
@@ -284,6 +297,30 @@ class VMAction(object):
 
         return info
 
+    @validation.schema(guest.resize_cpus)
+    def live_resize_cpus(self, userid, body):
+        cpu_cnt = body['cpu_cnt']
+        info = self.client.send_request('guest_live_resize_cpus',
+                                        userid, cpu_cnt)
+
+        return info
+
+    @validation.schema(guest.resize_mem)
+    def resize_mem(self, userid, body):
+        size = body['size']
+        info = self.client.send_request('guest_resize_mem',
+                                        userid, size)
+
+        return info
+
+    @validation.schema(guest.resize_mem)
+    def live_resize_mem(self, userid, body):
+        size = body['size']
+        info = self.client.send_request('guest_live_resize_mem',
+                                        userid, size)
+
+        return info
+
     @validation.schema(guest.deploy)
     def deploy(self, userid, body):
         image_name = body['image']
@@ -291,12 +328,14 @@ class VMAction(object):
         transportfiles = body.get('transportfiles', None)
         remotehost = body.get('remotehost', None)
         vdev = body.get('vdev', None)
+        hostname = body.get('hostname', None)
 
         request_info = ("action: 'deploy', userid: %(userid)s,"
                         "transportfiles: %(trans)s, remotehost: %(remote)s,"
                         "vdev: %(vdev)s" %
                         {'userid': userid, 'trans': transportfiles,
-                         'remote': remotehost, 'vdev': vdev
+                         'remote': remotehost, 'vdev': vdev,
+                         'hostname': hostname
                          })
 
         info = None
@@ -317,7 +356,7 @@ class VMAction(object):
                                             image_name,
                                             transportfiles=transportfiles,
                                             remotehost=remotehost,
-                                            vdev=vdev)
+                                            vdev=vdev, hostname=hostname)
         finally:
             try:
                 self.dd_semaphore.release()
@@ -513,7 +552,7 @@ def guest_action(req):
     req.response.body = utils.to_utf8(info_json)
     req.response.content_type = 'application/json'
     req.response.status = util.get_http_code_from_sdk_return(info,
-        additional_handler=util.handle_not_found)
+        additional_handler=util.handle_not_found_and_conflict)
     return req.response
 
 
