@@ -48,6 +48,13 @@ def get_test_image_list():
 get_test_image_list()
 
 
+def load_output(data):
+    # FIXME after we upgrade python3 to py36
+    if isinstance(data, bytes):
+        data = bytes.decode(data)
+    return json.loads(data)
+
+
 class TestzCCClient(object):
 
     def __init__(self):
@@ -83,10 +90,10 @@ class TestzCCClient(object):
         response = requests.request(method, url, data=body, headers=_headers)
         return response
 
-    def api_request(self, url, method='GET', body=None):
+    def api_request(self, url, method='GET', body=None, headers=None):
 
         full_uri = '%s%s' % (self.base_url, url)
-        return self.request(full_uri, method, body)
+        return self.request(full_uri, method, body, headers)
 
     def image_query(self, image_name):
         url = '/images?imagename=%s' % image_name
@@ -125,6 +132,25 @@ class TestzCCClient(object):
         url = '/images/%s/root_disk_size' % image_name
         return self.api_request(url=url, method='GET')
 
+    def _get_data_file(self, fpath):
+        if fpath:
+            return open(fpath, 'rb')
+
+    def file_import(self, fpath):
+        url = '/files'
+        headers = {'Content-Type': 'application/octet-stream'}
+        body = self._get_data_file(fpath)
+        return self.api_request(url=url, method='PUT', body=body,
+                                headers=headers)
+
+    def file_export(self, fpath):
+        url = '/files'
+        headers = {'Content-Type': 'application/octet-stream'}
+        body = {'source_file': fpath}
+        body = json.dumps(body)
+        return self.api_request(url=url, method='POST', body=body,
+                                headers=headers)
+
     def guest_create(self, userid, vcpus=1, memory=2048,
                      disk_list=[{"size": "5500", "is_boot_disk": "True"}],
                      user_profile=CONF.zvm.user_profile,
@@ -149,7 +175,7 @@ class TestzCCClient(object):
         return self.api_request(url=url, method='POST', body=body)
 
     def guest_deploy(self, userid, image_name=None, transportfiles=None,
-                     remotehost=None, vdev="100"):
+                     remotehost=None, vdev="100", hostname=None):
         if transportfiles is not None:
             body = """{"action": "deploy",
                       "image": "%s",
@@ -157,9 +183,15 @@ class TestzCCClient(object):
                       "transportfiles": "%s"}""" % (image_name, vdev,
                                                     transportfiles)
         else:
-            body = """{"action": "deploy",
-                   "image": "%s",
-                   "vdev": "%s"}""" % (image_name, vdev)
+            if hostname is not None:
+                body = """{"action": "deploy",
+                       "image": "%s",
+                       "vdev": "%s",
+                       "hostname": "%s"}""" % (image_name, vdev, hostname)
+            else:
+                body = """{"action": "deploy",
+                       "image": "%s",
+                       "vdev": "%s"}""" % (image_name, vdev)
 
         return self._guest_action(userid, body)
 
@@ -318,11 +350,38 @@ class TestzCCClient(object):
                    "cpu_cnt": %s}""" % cpu_cnt
         return self._guest_action(userid, body)
 
+    def guest_resize_memory(self, userid, memory):
+        body = {"action": "resize_mem",
+                "size": memory}
+        body = json.dumps(body)
+        return self._guest_action(userid, body)
+
+    def guest_pre_migrate_vm(self, userid):
+        body = {"action": "register_vm"}
+        body = json.dumps(body)
+        return self._guest_action(userid, body)
+
+    def guest_live_migrate_vm(self, userid, dest_zcc_userid,
+                         destination, parms, operation):
+        body = {"action": "live_migrate_vm",
+                   "dest_zcc_userid": dest_zcc_userid,
+                   "destination": destination,
+                   "parms": parms,
+                   "operation": operation}
+        body = json.dumps(body)
+        return self._guest_action(userid, body)
+
     def guest_live_resize_cpus(self, userid, cpu_cnt):
         body = """{"action": "live_resize_cpus",
                    "cpu_cnt": %s}""" % cpu_cnt
         return self._guest_action(userid, body)
 
+    def guest_live_resize_memory(self, userid, memory):
+        body = {"action": "live_resize_mem",
+                "size": memory}
+        body = json.dumps(body)
+        return self._guest_action(userid, body)
+
     def guest_reset(self, userid):
         body = '{"action": "reset"}'
         return self._guest_action(userid, body)
@@ -388,6 +447,20 @@ class TestzCCClient(object):
         body = '{"vswitch": {"grant_userid": "%s"}}' % userid
         return self.api_request(url=url, method='PUT', body=body)
 
+    def volume_attach(self, connection_info):
+        url = '/guests/volumes'
+        body = {'info': {'connection': connection_info}}
+        body_str = json.dumps(body)
+        return self.api_request(url=url, method='POST',
+                                body=body_str)
+
+    def volume_detach(self, connection_info):
+        url = '/guests/volumes'
+        body = {'info': {'connection': connection_info}}
+        body_str = json.dumps(body)
+        return self.api_request(url=url, method='DELETE',
+                                body=body_str)
+
 
 class ZVMConnectorTestUtils(object):
 
@@ -433,7 +506,7 @@ class ZVMConnectorTestUtils(object):
         resp = self.client.image_get_root_disk_size(image_name)
         errmsg = "failed to get image root disk size for %s" % image_name
         assert resp.status_code == 200, errmsg
-        return json.loads(resp.content)['output']
+        return load_output(resp.content)['output']
 
     def is_guest_exist(self, userid):
         cmd = 'sudo vmcp q %s' % userid
@@ -484,7 +557,8 @@ class ZVMConnectorTestUtils(object):
         resp_gcni = self.client.guest_create_network_interface(userid,
                                                    os_version, guest_networks)
         assert resp_gcni.status_code == 200, "Failed to create nif %s" % userid
-        nic_vdev = json.loads(resp_gcni.content)['output'][0]['nic_vdev']
+        output = load_output(resp_gcni.content)['output']
+        nic_vdev = output[0]['nic_vdev']
 
         self.client.guest_nic_couple_to_vswitch(userid, nic_vdev,
                                              CONF.tests.vswitch)
@@ -524,7 +598,7 @@ class ZVMConnectorTestUtils(object):
 
     def get_guest_power_state(self, userid):
         resp = self.client.guest_get_power_state(userid)
-        power_state = json.loads(resp.content)['output']
+        power_state = load_output(resp.content)['output']
         return power_state
 
     def wait_until_guest_in_power_state(self, userid, expect_state):
